==> elasticsearch-6.1.1-sources.jar: org/elasticsearch/action/admin/cluster/storedscripts/PutStoredScriptAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.storedscripts;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;


public class PutStoredScriptAction extends Action<PutStoredScriptRequest, PutStoredScriptResponse,
        PutStoredScriptRequestBuilder> {

    public static final PutStoredScriptAction INSTANCE = new PutStoredScriptAction();
    public static final String NAME = "cluster:admin/script/put";


    private PutStoredScriptAction() {
        super(NAME);
    }


    @Override
    public PutStoredScriptResponse newResponse() {
        return new PutStoredScriptResponse();
    }

    @Override
    public PutStoredScriptRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new PutStoredScriptRequestBuilder(client, this);
    }
}

==> elasticsearch-6.8.8-sources.jar: org/elasticsearch/action/admin/cluster/storedscripts/PutStoredScriptAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.storedscripts;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;
import org.elasticsearch.action.support.master.AcknowledgedResponse;


public class PutStoredScriptAction extends Action<PutStoredScriptRequest, AcknowledgedResponse,
        PutStoredScriptRequestBuilder> {

    public static final PutStoredScriptAction INSTANCE = new PutStoredScriptAction();
    public static final String NAME = "cluster:admin/script/put";


    private PutStoredScriptAction() {
        super(NAME);
    }


    @Override
    public AcknowledgedResponse newResponse() {
        return new AcknowledgedResponse();
    }

    @Override
    public PutStoredScriptRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new PutStoredScriptRequestBuilder(client, this);
    }
}
